import { Module } from "vuex";
import { ArgumentItem, ArgumentType } from "@/model/ArgumentItem";

const argumentStore: Module<any, any> = {
    state: {
        arguments: []
    },
    mutations: {
        ARGUMENTS(state, value) {
            state.arguments = [
                new ArgumentItem(ArgumentType.Gender, value[0]),
                new ArgumentItem(ArgumentType.BirthYear, value[1]),
                new ArgumentItem(ArgumentType.LoanPeriod, value[2]),
                new ArgumentItem(ArgumentType.NumberAts, value[3]),
            ]
        },
        SHAP_COMPLETE(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.Gender).positiveComplete = value.Gender >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.BirthYear).positiveComplete = value.BirthYear >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.LoanPeriod).positiveComplete = value.LoanPeriod >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.NumberAts).positiveComplete = value.NumberAts >= 0
        },
        SHAP_FALL(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.Gender).positiveFall = value.Gender >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.BirthYear).positiveFall = value.BirthYear >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.LoanPeriod).positiveFall = value.LoanPeriod >= 0
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.NumberAts).positiveFall = value.NumberAts >= 0
        },
        RESET_STATE_ARGUMENTS(state) {
            state.arguments = []
        },
    },
    actions: {
        shapComplete({ commit }, value) {
            commit('SHAP_COMPLETE', value)
        },
        shapFall({ commit }, value) {
            commit('SHAP_FALL', value)
        },
        arguments({ commit }, value) {
            commit('ARGUMENTS', value)
        },
        reset_state({commit}) {
            commit('RESET_STATE_ARGUMENTS')
        }
    },
    getters: {
        positiveArgumentsComplete: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveComplete: any; }) => x.positiveComplete)
        },
        positiveArgumentsFall: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveFall: boolean; }) => x.positiveFall)
        },
        negativeArgumentsComplete: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveComplete: boolean; }) => !x.positiveComplete)
        },
        negativeArgumentsFall: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveFall: boolean; }) => !x.positiveFall)
        },
    }
}

export default argumentStore
